@@ -1,16 +1,17 @@
 // SPDX-License-Identifier: (Apache-2.0 OR MIT)
+// Copyright ijl (2018-2025), Aviram Hassan (2020-2021), Nazar Kostetskyi (2022), Ben Sully (2021)
 
 use core::ffi::CStr;
 use core::ptr::{NonNull, null_mut};
-use once_cell::race::{OnceBool, OnceBox};
+use once_cell::race::OnceBox;
+use std::sync::OnceLock;
 
 use crate::ffi::{
     Py_DECREF, Py_False, Py_INCREF, Py_None, Py_True, Py_XDECREF, PyBool_Type, PyByteArray_Type,
-    PyBytes_Type, PyCapsule_Import, PyDateTime_CAPI, PyDateTime_IMPORT, PyDict_Type, PyErr_Clear,
-    PyErr_NewException, PyExc_TypeError, PyFloat_Type, PyImport_ImportModule, PyList_Type,
-    PyLong_Type, PyMapping_GetItemString, PyMemoryView_Type, PyObject, PyObject_GenericGetDict,
-    PyTuple_Type, PyTypeObject, PyUnicode_InternFromString, PyUnicode_New, PyUnicode_Type,
-    orjson_fragmenttype_new,
+    PyBytes_Type, PyDict_Type, PyErr_Clear, PyErr_NewException, PyExc_TypeError, PyFloat_Type,
+    PyImport_ImportModule, PyList_Type, PyLong_Type, PyMapping_GetItemString, PyMemoryView_Type,
+    PyObject, PyObject_GenericGetDict, PyTuple_Type, PyTypeObject, PyUnicode_InternFromString,
+    PyUnicode_New, PyUnicode_Type, orjson_fragmenttype_new,
 };
 
 pub(crate) static mut DEFAULT: *mut PyObject = null_mut();
@@ -73,7 +74,32 @@ unsafe fn look_up_type_object(module_name: &CStr, member_name: &CStr) -> *mut Py
     }
 }
 
-static INIT: OnceBool = OnceBool::new();
+#[cfg(not(PyPy))]
+unsafe fn look_up_datetime() {
+    unsafe {
+        crate::ffi::PyDateTime_IMPORT();
+        let datetime_capsule = crate::ffi::PyCapsule_Import(c"datetime.datetime_CAPI".as_ptr(), 1)
+            .cast::<crate::ffi::PyDateTime_CAPI>();
+        debug_assert!(!datetime_capsule.is_null());
+
+        DATETIME_TYPE = (*datetime_capsule).DateTimeType;
+        DATE_TYPE = (*datetime_capsule).DateType;
+        TIME_TYPE = (*datetime_capsule).TimeType;
+        ZONEINFO_TYPE = (*datetime_capsule).TZInfoType;
+    }
+}
+
+#[cfg(PyPy)]
+unsafe fn look_up_datetime() {
+    unsafe {
+        DATETIME_TYPE = look_up_type_object(c"datetime", c"datetime");
+        DATE_TYPE = look_up_type_object(c"datetime", c"date");
+        TIME_TYPE = look_up_type_object(c"datetime", c"time");
+        ZONEINFO_TYPE = look_up_type_object(c"zoneinfo", c"ZoneInfo");
+    }
+}
+
+static INIT: OnceLock<bool> = OnceLock::new();
 
 pub(crate) fn init_typerefs() {
     INIT.get_or_init(_init_typerefs_impl);
@@ -112,14 +138,7 @@ fn _init_typerefs_impl() -> bool {
         BYTEARRAY_TYPE = &raw mut PyByteArray_Type;
         MEMORYVIEW_TYPE = &raw mut PyMemoryView_Type;
 
-        PyDateTime_IMPORT();
-        let datetime_capsule =
-            PyCapsule_Import(c"datetime.datetime_CAPI".as_ptr(), 1).cast::<PyDateTime_CAPI>();
-
-        DATETIME_TYPE = (*datetime_capsule).DateTimeType;
-        DATE_TYPE = (*datetime_capsule).DateType;
-        TIME_TYPE = (*datetime_capsule).TimeType;
-        ZONEINFO_TYPE = (*datetime_capsule).TZInfoType;
+        look_up_datetime();
 
         UUID_TYPE = look_up_type_object(c"uuid", c"UUID");
         ENUM_TYPE = look_up_type_object(c"enum", c"EnumMeta");
@@ -147,11 +166,13 @@ fn _init_typerefs_impl() -> bool {
         Py_INCREF(JsonEncodeError);
         let json_jsondecodeerror =
             look_up_type_object(c"json", c"JSONDecodeError").cast::<PyObject>();
+        debug_assert!(!json_jsondecodeerror.is_null());
         JsonDecodeError = PyErr_NewException(
             c"orjson.JSONDecodeError".as_ptr(),
             json_jsondecodeerror,
             null_mut(),
         );
+        debug_assert!(!JsonDecodeError.is_null());
         Py_XDECREF(json_jsondecodeerror);
     };
     true
