@@ -1,4 +1,5 @@
 # SPDX-License-Identifier: (Apache-2.0 OR MIT)
+# Copyright ijl (2019-2025)
 
 import datetime
 
@@ -119,8 +120,15 @@ class TestDatetime:
             orjson.dumps(
                 [
                     datetime.datetime(
-                        2018, 1, 1, 2, 3, 4, 0, tzinfo=tz.gettz("Asia/Shanghai")
-                    )
+                        2018,
+                        1,
+                        1,
+                        2,
+                        3,
+                        4,
+                        0,
+                        tzinfo=tz.gettz("Asia/Shanghai"),
+                    ),
                 ],
                 option=orjson.OPT_NAIVE_UTC,
             )
@@ -135,9 +143,16 @@ class TestDatetime:
             orjson.dumps(
                 [
                     datetime.datetime(
-                        2018, 6, 1, 2, 3, 4, 0, tzinfo=datetime.timezone.utc
-                    )
-                ]
+                        2018,
+                        6,
+                        1,
+                        2,
+                        3,
+                        4,
+                        0,
+                        tzinfo=datetime.timezone.utc,
+                    ),
+                ],
             )
             == b'["2018-06-01T02:03:04+00:00"]'
         )
@@ -161,9 +176,16 @@ class TestDatetime:
             orjson.dumps(
                 [
                     datetime.datetime(
-                        2018, 6, 1, 2, 3, 4, 0, tzinfo=zoneinfo.ZoneInfo("UTC")
-                    )
-                ]
+                        2018,
+                        6,
+                        1,
+                        2,
+                        3,
+                        4,
+                        0,
+                        tzinfo=zoneinfo.ZoneInfo("UTC"),
+                    ),
+                ],
             )
             == b'["2018-06-01T02:03:04+00:00"]'
         )
@@ -182,8 +204,8 @@ class TestDatetime:
                         4,
                         0,
                         tzinfo=zoneinfo.ZoneInfo("Asia/Shanghai"),
-                    )
-                ]
+                    ),
+                ],
             )
             == b'["2018-01-01T02:03:04+08:00"]'
         )
@@ -202,20 +224,20 @@ class TestDatetime:
                         4,
                         0,
                         tzinfo=zoneinfo.ZoneInfo("America/New_York"),
-                    )
-                ]
+                    ),
+                ],
             )
             == b'["2018-06-01T02:03:04-04:00"]'
         )
 
-    @pytest.mark.skipif(pendulum is None, reason="pendulum install broken on win")
+    @pytest.mark.skipif(pendulum is None, reason="pendulum not installed")
     def test_datetime_pendulum_utc(self):
         """
         datetime.datetime UTC
         """
         assert (
             orjson.dumps(
-                [datetime.datetime(2018, 6, 1, 2, 3, 4, 0, tzinfo=pendulum.UTC)]
+                [datetime.datetime(2018, 6, 1, 2, 3, 4, 0, tzinfo=pendulum.UTC)],
             )
             == b'["2018-06-01T02:03:04+00:00"]'
         )
@@ -229,9 +251,16 @@ class TestDatetime:
             orjson.dumps(
                 [
                     datetime.datetime(
-                        2018, 1, 1, 2, 3, 4, 0, tzinfo=tz.gettz("Asia/Shanghai")
-                    )
-                ]
+                        2018,
+                        1,
+                        1,
+                        2,
+                        3,
+                        4,
+                        0,
+                        tzinfo=tz.gettz("Asia/Shanghai"),
+                    ),
+                ],
             )
             == b'["2018-01-01T02:03:04+08:00"]'
         )
@@ -245,14 +274,21 @@ class TestDatetime:
             orjson.dumps(
                 [
                     datetime.datetime(
-                        2018, 1, 1, 2, 3, 4, 0, tzinfo=pytz.timezone("Asia/Shanghai")
-                    )
-                ]
+                        2018,
+                        1,
+                        1,
+                        2,
+                        3,
+                        4,
+                        0,
+                        tzinfo=pytz.timezone("Asia/Shanghai"),
+                    ),
+                ],
             )
             == b'["2018-01-01T02:03:04+08:00"]'
         )
 
-    @pytest.mark.skipif(pendulum is None, reason="pendulum install broken on win")
+    @pytest.mark.skipif(pendulum is None, reason="pendulum not installed")
     def test_datetime_pendulum_positive(self):
         """
         datetime.datetime positive UTC
@@ -269,8 +305,8 @@ class TestDatetime:
                         4,
                         0,
                         tzinfo=pendulum.timezone("Asia/Shanghai"),  # type: ignore
-                    )
-                ]
+                    ),
+                ],
             )
             == b'["2018-01-01T02:03:04+08:00"]'
         )
@@ -284,14 +320,21 @@ class TestDatetime:
             orjson.dumps(
                 [
                     datetime.datetime(
-                        2018, 6, 1, 2, 3, 4, 0, tzinfo=pytz.timezone("America/New_York")
-                    )
-                ]
+                        2018,
+                        6,
+                        1,
+                        2,
+                        3,
+                        4,
+                        0,
+                        tzinfo=pytz.timezone("America/New_York"),
+                    ),
+                ],
             )
             == b'["2018-06-01T02:03:04-04:00"]'
         )
 
-    @pytest.mark.skipif(pendulum is None, reason="pendulum install broken on win")
+    @pytest.mark.skipif(pendulum is None, reason="pendulum not installed")
     def test_datetime_pendulum_negative_dst(self):
         """
         datetime.datetime negative UTC DST
@@ -308,8 +351,8 @@ class TestDatetime:
                         4,
                         0,
                         tzinfo=pendulum.timezone("America/New_York"),  # type: ignore
-                    )
-                ]
+                    ),
+                ],
             )
             == b'["2018-06-01T02:03:04-04:00"]'
         )
@@ -331,8 +374,8 @@ class TestDatetime:
                         4,
                         0,
                         tzinfo=zoneinfo.ZoneInfo("America/New_York"),
-                    )
-                ]
+                    ),
+                ],
             )
             == b'["2018-12-01T02:03:04-05:00"]'
         )
@@ -354,13 +397,13 @@ class TestDatetime:
                         4,
                         0,
                         tzinfo=pytz.timezone("America/New_York"),
-                    )
-                ]
+                    ),
+                ],
             )
             == b'["2018-12-01T02:03:04-05:00"]'
         )
 
-    @pytest.mark.skipif(pendulum is None, reason="pendulum install broken on win")
+    @pytest.mark.skipif(pendulum is None, reason="pendulum not installed")
     def test_datetime_pendulum_negative_non_dst(self):
         """
         datetime.datetime negative UTC non-DST
@@ -377,8 +420,8 @@ class TestDatetime:
                         4,
                         0,
                         tzinfo=pendulum.timezone("America/New_York"),  # type: ignore
-                    )
-                ]
+                    ),
+                ],
             )
             == b'["2018-12-01T02:03:04-05:00"]'
         )
@@ -400,8 +443,8 @@ class TestDatetime:
                         4,
                         0,
                         tzinfo=zoneinfo.ZoneInfo("Australia/Adelaide"),
-                    )
-                ]
+                    ),
+                ],
             )
             == b'["2018-12-01T02:03:04+10:30"]'
         )
@@ -423,13 +466,13 @@ class TestDatetime:
                         4,
                         0,
                         tzinfo=pytz.timezone("Australia/Adelaide"),
-                    )
-                ]
+                    ),
+                ],
             )
             == b'["2018-12-01T02:03:04+10:30"]'
         )
 
-    @pytest.mark.skipif(pendulum is None, reason="pendulum install broken on win")
+    @pytest.mark.skipif(pendulum is None, reason="pendulum not installed")
     def test_datetime_pendulum_partial_hour(self):
         """
         datetime.datetime UTC offset partial hour
@@ -446,13 +489,13 @@ class TestDatetime:
                         4,
                         0,
                         tzinfo=pendulum.timezone("Australia/Adelaide"),  # type: ignore
-                    )
-                ]
+                    ),
+                ],
             )
             == b'["2018-12-01T02:03:04+10:30"]'
         )
 
-    @pytest.mark.skipif(pendulum is None, reason="pendulum install broken on win")
+    @pytest.mark.skipif(pendulum is None, reason="pendulum not installed")
     def test_datetime_partial_second_pendulum_supported(self):
         """
         datetime.datetime UTC offset round seconds
@@ -471,8 +514,8 @@ class TestDatetime:
                         27,
                         87,
                         tzinfo=pendulum.timezone("Europe/Amsterdam"),  # type: ignore
-                    )
-                ]
+                    ),
+                ],
             )
             in AMSTERDAM_1937_DATETIMES
         )
@@ -496,8 +539,8 @@ class TestDatetime:
                         27,
                         87,
                         tzinfo=zoneinfo.ZoneInfo("Europe/Amsterdam"),
-                    )
-                ]
+                    ),
+                ],
             )
             in AMSTERDAM_1937_DATETIMES
         )
@@ -521,8 +564,8 @@ class TestDatetime:
                         27,
                         87,
                         tzinfo=pytz.timezone("Europe/Amsterdam"),
-                    )
-                ]
+                    ),
+                ],
             )
             in AMSTERDAM_1937_DATETIMES
         )
@@ -538,9 +581,16 @@ class TestDatetime:
             orjson.dumps(
                 [
                     datetime.datetime(
-                        1937, 1, 1, 12, 0, 27, 87, tzinfo=tz.gettz("Europe/Amsterdam")
-                    )
-                ]
+                        1937,
+                        1,
+                        1,
+                        12,
+                        0,
+                        27,
+                        87,
+                        tzinfo=tz.gettz("Europe/Amsterdam"),
+                    ),
+                ],
             )
             in AMSTERDAM_1937_DATETIMES
         )
@@ -593,7 +643,8 @@ class TestDatetime:
         """
         assert (
             orjson.dumps(
-                [datetime.time(2, 3, 4, 123)], option=orjson.OPT_OMIT_MICROSECONDS
+                [datetime.time(2, 3, 4, 123)],
+                option=orjson.OPT_OMIT_MICROSECONDS,
             )
             == b'["02:03:04"]'
         )
@@ -630,7 +681,8 @@ class TestDatetime:
         """
         assert (
             orjson.dumps(
-                [datetime.datetime(2000, 1, 1, 2, 3, 4, 123)], option=orjson.OPT_UTC_Z
+                [datetime.datetime(2000, 1, 1, 2, 3, 4, 123)],
+                option=orjson.OPT_UTC_Z,
             )
             == b'["2000-01-01T02:03:04.000123"]'
         )
@@ -644,8 +696,15 @@ class TestDatetime:
             orjson.dumps(
                 [
                     datetime.datetime(
-                        2000, 1, 1, 0, 0, 0, 1, tzinfo=datetime.timezone.utc
-                    )
+                        2000,
+                        1,
+                        1,
+                        0,
+                        0,
+                        0,
+                        1,
+                        tzinfo=datetime.timezone.utc,
+                    ),
                 ],
                 option=orjson.OPT_UTC_Z,
             )
@@ -655,15 +714,22 @@ class TestDatetime:
             orjson.dumps(
                 [
                     datetime.datetime(
-                        1937, 1, 1, 12, 0, 27, 87, tzinfo=tz.gettz("Europe/Amsterdam")
-                    )
+                        1937,
+                        1,
+                        1,
+                        12,
+                        0,
+                        27,
+                        87,
+                        tzinfo=tz.gettz("Europe/Amsterdam"),
+                    ),
                 ],
                 option=orjson.OPT_UTC_Z,
             )
             in AMSTERDAM_1937_DATETIMES_WITH_Z
         )
 
-    @pytest.mark.skipif(pendulum is None, reason="pendulum install broken on win")
+    @pytest.mark.skipif(pendulum is None, reason="pendulum not installed")
     def test_datetime_roundtrip(self):
         """
         datetime.datetime parsed by pendulum
@@ -738,9 +804,13 @@ class TestTime:
             orjson.dumps(
                 [
                     datetime.time(
-                        12, 15, 59, 111, tzinfo=zoneinfo.ZoneInfo("Asia/Shanghai")
-                    )
-                ]
+                        12,
+                        15,
+                        59,
+                        111,
+                        tzinfo=zoneinfo.ZoneInfo("Asia/Shanghai"),
+                    ),
+                ],
             )
 
     def test_time_microsecond_max(self):
@@ -760,19 +830,22 @@ class TestDateclassPassthrough:
     def test_passthrough_datetime(self):
         with pytest.raises(orjson.JSONEncodeError):
             orjson.dumps(
-                datetime.datetime(1970, 1, 1), option=orjson.OPT_PASSTHROUGH_DATETIME
+                datetime.datetime(1970, 1, 1),
+                option=orjson.OPT_PASSTHROUGH_DATETIME,
             )
 
     def test_passthrough_date(self):
         with pytest.raises(orjson.JSONEncodeError):
             orjson.dumps(
-                datetime.date(1970, 1, 1), option=orjson.OPT_PASSTHROUGH_DATETIME
+                datetime.date(1970, 1, 1),
+                option=orjson.OPT_PASSTHROUGH_DATETIME,
             )
 
     def test_passthrough_time(self):
         with pytest.raises(orjson.JSONEncodeError):
             orjson.dumps(
-                datetime.time(12, 0, 0), option=orjson.OPT_PASSTHROUGH_DATETIME
+                datetime.time(12, 0, 0),
+                option=orjson.OPT_PASSTHROUGH_DATETIME,
             )
 
     def test_passthrough_datetime_default(self):
